Documentation
¶
Overview ¶
Package task defines the task model for agent work items. Persistence is handled by the workflow engine's pipeline DB steps.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Task ¶
type Task struct {
ID string `json:"id"`
Title string `json:"title"`
Description string `json:"description"`
Status Status `json:"status"`
Priority Priority `json:"priority"`
AssignedTo string `json:"assigned_to,omitempty"`
TeamID string `json:"team_id,omitempty"`
ParentID string `json:"parent_id,omitempty"`
DependsOn []string `json:"depends_on,omitempty"`
Labels []string `json:"labels,omitempty"`
Metadata map[string]string `json:"metadata,omitempty"`
Result string `json:"result,omitempty"`
Error string `json:"error,omitempty"`
CreatedAt time.Time `json:"created_at"`
UpdatedAt time.Time `json:"updated_at"`
StartedAt *time.Time `json:"started_at,omitempty"`
CompletedAt *time.Time `json:"completed_at,omitempty"`
}
Task is a unit of work for an agent.
Click to show internal directories.
Click to hide internal directories.